
import ImageColorCard from "@/components/images/ImageColorCard";
import { Color, Image, ImageColor, ImageVariant } from "@/generated/prisma";

type ColorWithItems = Color & {
  images: (ImageColor & {
    image: Image & {
      variants: ImageVariant[]
    }
  })[]
}

export default function DisplayColor({ color }: { color: ColorWithItems }) {


  return (
    <div className="space-y-6">
      <div>
        <h1 className="text-2xl font-bold">{color.name}</h1>
      </div>

      <div className="flex flex-wrap gap-2">
        <div
          key={color.id}
          className="w-10 h-10 rounded-full border"
          style={{ backgroundColor: color.hex ?? "#ccc" }}
          title={color.hex ?? "n/a"}
        />
      </div>

      <div>
        <h2 className="text-xl font-semibold">Used by {color.images.length} image(s)</h2>
        <div className="grid grid-cols-2 md:grid-cols-4 gap-4 mt-2">
          {color.images.map((image) => (
            <ImageColorCard key={image.id} image={image} />
          ))}
        </div>
      </div>
    </div>
  );
}