import { Card, CardContent, CardFooter, CardHeader, CardTitle } from "@/components/ui/card";
import { ExtractColor } from "@/generated/prisma";
import Link from "next/link";

type ColorsWithItems = ExtractColor & {
  images: { id: string }[]
}

export default function ListExtractColors({ colors }: { colors: ColorsWithItems[] }) {
  return (
    <div className="grid gap-6 sm:grid-cols-2 md:grid-cols-3 xl:grid-cols-4">
      {colors.map((col) => (
        <Link href={`/extract/${col.id}`} key={col.id}>
          <Card className="overflow-hidden">
            <CardHeader>
              <CardTitle className="text-base truncate">{col.name}</CardTitle>
            </CardHeader>
            <CardContent>
              <div className="flex flex-wrap gap-2">
                <div
                  className="w-10 h-10 rounded-full border"
                  style={{ backgroundColor: col.hex ?? "#ccc" }}
                  title={col.hex ?? "n/a"}
                />
              </div>
            </CardContent>
            <CardFooter>
              Used by {col.images.length} image{col.images.length !== 1 ? "s" : ""}
            </CardFooter>
          </Card>
        </Link>
      ))}
    </div>
  );
}